@@ -1,7 +1,7 @@
 package App::hr;
 
-our $DATE = '2015-08-19'; # DATE
-our $VERSION = '0.21'; # VERSION
+our $DATE = '2015-08-20'; # DATE
+our $VERSION = '0.22'; # VERSION
 
 use feature 'say';
 use strict 'subs', 'vars';
@@ -111,6 +111,24 @@ _
         random_color => {
             schema => ['bool', is=>1],
         },
+        height => {
+            summary => 'Specify height (number of rows)',
+            schema => ['int*', min=>1],
+            default => 1,
+            cmdline_aliases => {H=>{}},
+        },
+        space_before => {
+            summary => 'Number of empty rows before drawing the bar',
+            schema => ['int*', min=>0],
+            default => 0,
+            cmdline_aliases => {b=>{}},
+        },
+        space_after => {
+            summary => 'Number of empty rows after drawing the bar',
+            schema => ['int*', min=>0],
+            default => 0,
+            cmdline_aliases => {a=>{}},
+        },
         pattern => {
             summary => 'Specify a pattern',
             schema => 'str*',
@@ -174,6 +192,12 @@ sub hr_app {
     }
 
     my $res = hr($args{pattern}, $args{color});
+    $res = join(
+        "",
+        ("\n" x ($args{space_before} // 0)),
+        ("$res\n" x ($args{height} // 1)),
+        ("\n" x ($args{space_after} // 0)),
+    );
 
     [200, "OK", $res];
 }
@@ -193,7 +217,7 @@ App::hr - Print horizontal bar on the terminal
 
 =head1 VERSION
 
-This document describes version 0.21 of App::hr (from Perl distribution App-hr), released on 2015-08-19.
+This document describes version 0.22 of App::hr (from Perl distribution App-hr), released on 2015-08-20.
 
 =head1 SYNOPSIS
 
@@ -236,8 +260,9 @@ will move a line down when printing at the last column.
 
 =head2 hr_app(%args) -> [status, msg, result, meta]
 
-Print horizontal bar on the terminal.
+{en_US Print horizontal bar on the terminal}.
 
+{en_US 
 C<hr> can be useful as a marker/separator, especially if you use other commands
 that might produce a lot of output, and you need to scroll back lots of pages to
 see previous output. Example:
@@ -277,6 +302,7 @@ Usage:
  % hr --help
 
 If you use Perl, you can also use the C<hr> function in C<App::hr> module.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -284,16 +310,28 @@ Arguments ('*' denotes required arguments):
 
 =item * B<color> => I<str>
 
-Specify a color (see Term::ANSIColor).
+{en_US Specify a color (see Term::ANSIColor)}.
+
+=item * B<height> => I<int> (default: 1)
+
+{en_US Specify height (number of rows)}.
 
 =item * B<pattern> => I<str>
 
-Specify a pattern.
+{en_US Specify a pattern}.
 
 =item * B<random_color> => I<bool>
 
 =item * B<random_pattern> => I<bool>
 
+=item * B<space_after> => I<int> (default: 0)
+
+{en_US Number of empty rows after drawing the bar}.
+
+=item * B<space_before> => I<int> (default: 0)
+
+{en_US Number of empty rows before drawing the bar}.
+
 =back
 
 Returns an enveloped result (an array).
